7. References — ESIBD Explorer 0.6 documentation

# 7. References

[1]

Grant E. Johnson, Don Gunaratne, and Julia Laskin. Soft- and reactive landing of ions onto surfaces: Concepts and applications. Mass Spectrom. Rev., 35(3):439–479, May 2016. doi:10.1002/mas.21451.

[2]

Jobin Cyriac, T. Pradeep, H. Kang, R. Souda, and R. G. Cooks. Low-Energy Ionic Collisions at Molecular Solids. Chem. Rev., 112(10):5356–5411, October 2012. doi:10.1021/cr200384k.

[3]

Lukas Krumbein, Kelvin Anggara, Martina Stella, Tomasz Michnowicz, Hannah Ochner, Sabine Abb, Gordon Rinke, André Portz, Michael Dürr, Uta Schlickum, Andrew Baldwin, Andrea Floris, Klaus Kern, and Stephan Rauschenbach. Fast Molecular Compression by a Hyperthermal Collision Gives Bond-Selective Mechanochemistry. Phys. Rev. Lett., 126(5):056001, February 2021. doi:10.1103/PhysRevLett.126.056001.

[4]

C Hamann, R Woltmann, I-Po Hong, N. Hauptmann, S. Karan, and R. Berndt. Ultrahigh vacuum deposition of organic molecules by electrospray ionization. Review of Scientific Instruments, 82(3):033903, March 2011. doi:10.1063/1.3553010.

[5]

Stephan Rauschenbach, Markus Ternes, Ludger Harnau, and Klaus Kern. Mass Spectrometry as a Preparative Tool for the Surface Science of Large Molecules. Annu. Rev. Anal. Chem., 9(1):473–498, 2016. doi:10.1146/annurev-anchem-071015-041633.

[6]

Sabine Abb, Ludger Harnau, Rico Gutzler, Stephan Rauschenbach, and Klaus Kern. Two-dimensional honeycomb network through sequence-controlled self-assembly of oligopeptides. Nat Commun, 7(1):1–7, January 2016. doi:10.1038/ncomms10335.

[7]

Zhitao Deng, Nicha Thontasen, Nikola Malinowski, Gordon Rinke, Ludger Harnau, Stephan Rauschenbach, and Klaus Kern. A Close Look at Proteins: Submolecular Resolution of Two- and Three-Dimensionally Folded Cytochrome c at Surfaces. Nano Lett., 12(5):2452–2458, May 2012. doi:10.1021/nl3005385.

[8]

Gordon Rinke, Stephan Rauschenbach, Ludger Harnau, Alyazan Albarghash, Matthias Pauly, and Klaus Kern. Active Conformation Control of Unfolded Proteins by Hyperthermal Collision with a Metal Surface. Nano Letters, 14(10):5609–5615, October 2014. doi:10.1021/nl502122j.

[9]

X. Wu, M. Delbianco, K. Anggara, T. Michnowicz, A. Pardo-Vargas, P. Bharate, S. Sen, M. Pristl, S. Rauschenbach, U. Schlickum, S. Abb, P. H. Seeberger, and K. Kern. Imaging single glycans. Nature, 582(7812):375–378, June 2020. doi:10.1038/s41586-020-2362-1.

[10]

Paul Fremdling, Tim K. Esser, Bodhisattwa Saha, Alexander A. Makarov, Kyle L. Fort, Maria Reinhardt-Szyba, Joseph Gault, and Stephan Rauschenbach. A Preparative Mass Spectrometer to Deposit Intact Large Native Protein Complexes. ACS Nano, 16(9):14443–14455, August 2022. doi:10.1021/acsnano.2c04831.

[11]

Victor A. Mikhailov, Todd H. Mize, Justin L. P. Benesch, and Carol V. Robinson. Mass-Selective Soft-Landing of Protein Assemblies with Controlled Landing Energies. Anal. Chem., 86(16):8321–8328, August 2014. doi:10.1021/ac5018327.

[12]

Venkateshkumar Prabhakaran, B. Layla Mehdi, Jeffrey J. Ditto, Mark H. Engelhard, Bingbing Wang, K. Don D. Gunaratne, David C. Johnson, Nigel D. Browning, Grant E. Johnson, and Julia Laskin. Rational design of efficient electrode–electrolyte interfaces for solid-state energy storage using ion soft landing. Nat. Comm., 7:11399, April 2016. doi:10.1038/ncomms11399.

[13]

N. Vats, S. Rauschenbach, W. Sigle, S. Sen, S. Abb, A. Portz, M. Dürr, M. Burghard, P. A. van Aken, and K. Kern. Electron microscopy of polyoxometalate ions on graphene by electrospray ion beam deposition. Nanoscale, 10(10):4952–4961, March 2018. doi:10.1039/C8NR00402A.

[14]

Tim K. Esser, Jan Boehning, Paul Fremdling, Mark T. Agasid, Adam Costin, Kyle Fort, Albert Konijnenberg, Alan Bahm, Alexander Makarov, Carol V. Robinson, Justin L. P. Benesch, Lindsay Baker, Tanmay A. M. Bharat, Joseph Gault, and Stephan Rauschenbach. Mass-selective and ice-free cryo-EM protein sample preparation via native electrospray ion-beam deposition. PNAS Nexus, 1(4):pgac153, August 2022. doi:10.1101/2021.10.18.464782.

[15]

Tim K. Esser, Jan Böhning, Paul Fremdling, Tanmay Bharat, Joseph Gault, and Stephan Rauschenbach. Cryo-EM samples of gas-phase purified protein assemblies using native electrospray ion-beam deposition. Faraday Discuss., 240:67–80, September 2022. doi:10.1039/D2FD00065B.

[16]

Jean-Nicolas Longchamp, Stephan Rauschenbach, Sabine Abb, Conrad Escher, Tatiana Latychevskaia, Klaus Kern, and Hans-Werner Fink. Imaging proteins at the single-molecule level. PNAS, 114(7):1474–1479, February 2017. doi:10.1073/pnas.1614519114.

[17]

Hannah Ochner, Sven Szilagyi, Sabine Abb, Joseph Gault, Carol V. Robinson, Luigi Malavolti, Stephan Rauschenbach, and Klaus Kern. Low-energy electron holography imaging of conformational variability of single-antibody molecules from electrospray ion beam deposition. PNAS, 118(51):e2112651118, December 2021. doi:10.1073/pnas.2112651118.

[18]

Hannah Ochner, Stephan Rauschenbach, and Luigi Malavolti. Electrospray ion beam deposition plus low-energy electron holography as a tool for imaging individual biomolecules. Essays in Biochemistry, 67(2):151–163, March 2023. doi:10.1042/EBC20220165.

[19]

Kelvin Anggara, Yuntao Zhu, Martina Delbianco, Stephan Rauschenbach, Sabine Abb, Peter H. Seeberger, and Klaus Kern. Exploring the Molecular Conformation Space by Soft Molecule–Surface Collision. J. Am. Chem. Soc., 142(51):21420–21427, November 2020. doi:10.1021/jacs.0c09933.

[20]

Michael Volný, W. Timothy Elam, Andrew Branca, Buddy D. Ratner, and František Tureček. Preparative Soft and Reactive Landing of Multiply Charged Protein Ions on a Plasma-Treated Metal Surface. Analytical Chemistry, 77(15):4890–4896, August 2005. doi:10.1021/ac0507136.

[21]

Stephan Rauschenbach, Ralf Vogelgesang, N. Malinowski, Jürgen W. Gerlach, Mohamed Benyoucef, Giovanni Costantini, Zhitao Deng, Nicha Thontasen, and Klaus Kern. Electrospray Ion Beam Deposition: Soft-Landing and Fragmentation of Functional Molecules at Solid Surfaces. ACS Nano, 3(10):2901–2910, October 2009. doi:10.1021/nn900022p.

[22]

Tim K. Esser, Jan Böhning, Alpcan Önür, Dinesh K. Chinthapalli, Lukas Eriksson, Marko Grabarics, Paul Fremdling, Albert Konijnenberg, Alexander Makarov, Aurelien Botman, Christine Peter, Justin L. P. Benesch, Carol V. Robinson, Joseph Gault, Lindsay Baker, Tanmay A. M. Bharat, and Stephan Rauschenbach. Cryo-EM of soft-landed β-galactosidase: Gas-phase and native structures are remarkably similar. August 2023. doi:10.1101/2023.08.17.553673.

[23]

Tim K. Esser. A Cryogenic Mass Spectrometer for Action Spectroscopy of Single Nanoparticles. PhD thesis, Universität Leipzig, Leipzig, 2019.